# pySESL

## Introduction

This repo contains a partial port of the [Semi-Empirical Sea Level (SESL) model](https://github.com/bobkopp/SESL) into Python. As of 7/2021 it is quite incomplete in that it only contains a few functions necessary to project sea levels from a global mean surface temperature (GMST) time series *after* having already trained the SESL model on historical reconstructions of temperature and sea level. Future work may increase the functionality.

## Installation

```python
pip install pySESL
```